; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------

;Akigiyama missiles super
[Command]
name = AMissileSuper
command = ~D, DF, F,x+y+z

;B-ko Storm super
[Command]
name = BKS
command = ~D, DB, B,x+y+z

;Robo-Ako super
[Command]
name= RoboAko
command = ~D, DF, F,z+c

;Arashiyama V super (level 3 only!)
[Command]
name = CallA5
command = ~D, DB, B,z+c

;Spider-Lift
[Command]
name = TankThrow
command =~D, DF, F,a+b+c

;-| Special Motions |------------------------------------------------------
;-----------------
; QCF
[Command]
name = QCF_a
command = ~D, DF, F, a

[Command]
name = QCF_b
command = ~D, DF, F, b

[Command]
name = QCF_c
command = ~D, DF, F, c

[Command]
name = QCF_x
command = ~D, DF, F, x

[Command]
name = QCF_y
command = ~D, DF, F, y

[Command]
name = QCF_z
command = ~D, DF, F, z

;-----------------
; QCB
[Command]
name = QCB_a
command = ~D, DB, B, a

[Command]
name = QCB_b
command = ~D, DB, B, b

[Command]
name = QCB_c
command = ~D, DB, B, c

[Command]
name = QCB_x
command = ~D, DB, B, x

[Command]
name = QCB_y
command = ~D, DB, B, y

[Command]
name = QCB_z
command = ~D, DB, B, z

;-----------------
; Uppercut
[Command]
name = uppercut_a
command = ~F, D, DF, a

[Command]
name = uppercut_b
command = ~F, D, DF, b

[Command]
name = uppercut_c
command = ~F, D, DF, c

[Command]
name = uppercut_x
command = ~F, D, DF, x

[Command]
name = uppercut_y
command = ~F, D, DF, y

[Command]
name = uppercut_z
command = ~F, D, DF, z


;--------------------
;Charge_Down_up
[Command]
name = chargedownup_a
command = ~60$D, U, a
time = 10

[Command]
name = chargedownup_b
command = ~60$D, U, b
time = 10

[Command]
name = chargedownup_c
command = ~60$D, U, c
time = 10

[Command]
name = chargedownup_x
command = ~60$D, U, x
time = 10

[Command]
name = chargedownup_y
command = ~60$D, U, y
time = 10

[Command]
name = chargedownup_z
command = ~60$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
name = chargebackfwd_a
command = ~60$B, F, a
time = 10

[Command]
name = chargebackfwd_b
command = ~60$B, F, b
time = 10

[Command]
name = chargedownup_c
command = ~60$D, U, c
time = 10

[Command]
name = chargedownup_x
command = ~60$D, U, x
time = 10

[Command]
name = chargedownup_y
command = ~60$D, U, y
time = 10

[Command]
name = chargedownup_z
command = ~60$D, U, z
time = 10



;-| Double Tap |-----------------------------------------------------------
[Command]
name = FF       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = BB       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = recovery ;Required (do not remove)
command = a+b
time = 1

[Command]
name = ab
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = fwd_a
command = /F,a
time = 1

[Command]
name = fwd_b
command = /F,b
time = 1

[Command]
name = fwd_c
command = /F,c
time = 1

[Command]
name = fwd_x
command = /F,x
time = 1

[Command]
name = fwd_y
command = /F,y
time = 1

[Command]
name = fwd_z
command = /F,z
time = 1

[Command]
name = back_a
command = /B,a
time = 1

[Command]
name = back_b
command = /B,b
time = 1

[Command]
name = back_c
command = /B,c
time = 1

[Command]
name = back_z
command = /B,z
time = 1

[Command]
name = down_a
command = /$D,a
time = 1

[Command]
name = down_b
command = /$D,b
time = 1

[Command]
name = down_c
command = /$D,c
time = 1

[Command]
name = down_x
command = /$D,x
time = 1

[Command]
name = down_y
command = /$D,y
time = 1

[Command]
name = down_z
command = /$D,z
time = 1

[Command]
name = fwd_ab
command = /F, a+b
time = 1

[Command]
name = back_ab
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = a
command = a
time = 1

[Command]
name = b
command = b
time = 1

[Command]
name = c
command = c
time = 1

[Command]
name = x
command = x
time = 1

[Command]
name = y
command = y
time = 1

[Command]
name = z
command = z
time = 1


[Command]
name = s
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = holdfwd  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = holdback ;Required (do not remove)
command = /$B
time = 1

[Command]
name = holdup   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = holddown ;Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = FF
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = BB
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Standing throw
[State -1]
type = ChangeState
value = 800
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = fwd_z   ;p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = fwd_z   ;p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
trigger3 = command = back_z  ;p2 stand
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = back_z  ;p2 crouch
trigger4 = p2statetype = C
trigger4 = p2movetype != H
;---------------------------------------------------------------------------
;Air_Throw1 (close dir+Z)

[State -1]
type = ChangeState
value = 1119
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = fwd_z
trigger2 = command = back_z


;===========================================================================
;---------------------------------------------------------------------------
;super akigiyama missiles- ground
[State -1]
type= changestate
value= 3000
triggerall= command = AMissileSuper
triggerall= power >= 1000
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger2 = movecontact =1
trigger2 = statetype !=A

;super akigiyama missiles- air
[State -1]
type= changestate
value= 3010
triggerall= command = AMissileSuper
triggerall= power >= 1000
trigger1 = ctrl = 1
trigger1 = statetype = A
trigger2 = movecontact =1
trigger2 = statetype =A

;B-ko storm!
[State -1]
type= changestate
value= 3020
triggerall= command = BKS
triggerall= power >= 1000
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger2 = movecontact =1
trigger2 = statetype !=A
trigger2 = stateno <= 3000

;Go RoboAko!
[State -1]
type= changestate
value= 3100
triggerall= command = RoboAko
triggerall= power >= 1000
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger2 = movecontact =1
trigger2 = statetype !=A
trigger2 = stateno <= 3000

;Arashiyama V super (level 3 only)
[State -1]
type= changestate
value= 3200
triggerall= command = CallA5
triggerall= power >= 3000
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger2 = movecontact =1
trigger2 = statetype !=A
trigger2 = stateno <= 3000

;'Spider Lift!' super- only 1 level
[State -1]
type= Changestate
value = 3400
triggerall = command = TankThrow
triggerall = statetype = S
triggerall = backedgebodydist < 80
triggerall = power >=1000
trigger1 = ctrl = 1


;Special spider-lift trigger Vs. A-ko
[State -1]
type= Changestate
value = 3400
triggerall = statetype = S
triggerall = backedgebodydist < 80
triggerall = power >=1000
triggerall = ctrl = 1
triggerall = p2name = Eiko Magami 
triggerall = p2stateno = 3200
trigger1 = command = a
trigger2 = command = b
trigger3 = command = c
trigger4 = command = x
trigger5 = command = y
trigger6 = command = z

;Ground Akigiyama Missiles Z
[State -1]
type = Changestate
value = 1000
triggerall = command = QCF_z
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger2 = movecontact =1
trigger2 = statetype !=A

;Ground Akigiyama Missiles Y
[State -1]
type = Changestate
value = 1001
triggerall = command = QCF_y
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger2 = movecontact =1
trigger2 = statetype !=A

;Ground Akigiyama Missiles X
[State -1]
type = Changestate
value = 1002
triggerall = command = QCF_x
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger2 = movecontact =1
trigger2 = statetype !=A

;Air Akigiyama Missiles Z
[State -1]
type = Changestate
value = 1030
triggerall = command = QCF_z
trigger1 = ctrl = 1
trigger1 = statetype = A
trigger2 = movecontact =1
trigger2 = statetype = A

;Air Akigiyama Missiles Y
[State -1]
type = Changestate
value = 1031
triggerall = command = QCF_y
trigger1 = ctrl = 1
trigger1 = statetype = A
trigger2 = movecontact =1
trigger2 = statetype = A

;Air Akigiyama Missiles X
[State -1]
type = Changestate
value = 1032
triggerall = command = QCF_x
trigger1 = ctrl = 1
trigger1 = statetype = A
trigger2 = movecontact =1
trigger2 = statetype = A

;Muscle attack! (Z)
[State -1]
type = Changestate
value = 1060
triggerall = command = down_z
triggerall = statetype = A
trigger1 = ctrl = 1

;stiletto leap (c)
[State -1]
type = Changestate
value = 1070
triggerall = command = QCF_c
triggerall = statetype = S
trigger1 = ctrl = 1

;stiletto leap (b)
[State -1]
type = Changestate
value = 1073
triggerall = command = QCF_b
triggerall = statetype = S
trigger1 = ctrl = 1

;stiletto leap (c)
[State -1]
type = Changestate
value = 1075
triggerall = command = QCF_a
triggerall = statetype = S
trigger1 = ctrl = 1

;Blackjackamimi lash
[State -1]
type = Changestate
value = 1100
triggerall = command = QCB_z
triggerall = statetype = S
trigger1 = ctrl = 1

;Diving takedown
[State -1]
type = Changestate
value = 1200
trigger1 = stateno = 100
trigger1 = command = z

;special throw
[State -1]
type = changestate
value = 849 
trigger1= command = QCB_c
trigger1= ctrl = 1
trigger1=statetype = S

;Stand_A- light kick high
[State -1]
type = ChangeState
value = 200
triggerall = command = a          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;rapid-fire after light kick low
trigger2 = stateno = 202
trigger2 = time >= 8

;Stand_A- light kick middle
[State -1]
type = ChangeState
value = 201
triggerall = command = a          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
 ;rapid-fire after light kick high
trigger1 = stateno = 200
trigger1 = time >= 8

;Stand_A- light kick low
[State -1]
type = ChangeState
value = 202
triggerall = command = a          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
 ;rapid-fire after light kick middle
trigger1 = stateno = 201
trigger1 = time >= 8


;---------------------------------------------------------------------------
;Stand_B- long range medium back kick
[State -1]
type = ChangeState
value = 210
triggerall = command = b
triggerall = command != holddown
triggerall = P2BodyDist X > 20
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;chain from light kicks (200 to 202)
trigger2 = stateno >= 200
trigger2 = stateno <= 202
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
;chains from standing jab (230 & 231)
trigger3= stateno >=230
trigger3= stateno <=231
trigger3= movecontact = 1

;---------------------------------------------------------------------------
;Stand_B- shorter range axe-kick
[State -1]
type = ChangeState
value = 211
triggerall = command = b
triggerall = command != holddown
triggerall = P2BodyDist X <= 20
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;chain from light kicks (200 to 202)
trigger2 = stateno >= 200
trigger2 = stateno <= 202
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
;chains from standing jab (230 & 231)
trigger3= stateno >=230
trigger3= stateno <=231
trigger3= movecontact = 1
;---------------------------------------------------------------------------
;Stand_C- standing spinkick
[State -1]
type = ChangeState
value = 220
triggerall = command = c
triggerall = command != holddown
triggerall = P2Bodydist X <= 25
trigger1 = statetype = S
trigger1 = ctrl = 1
;chains from standing light or medium attacks (kicks, 200 to 210)
trigger2 = stateno >= 200
trigger2 = stateno <= 211
trigger2 = movecontact = 1
;punches (230 to 240)
trigger3 = stateno >= 230
trigger3 = stateno <= 242
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_C- jumping spinkick
[State -1]
type = ChangeState
value = 221
triggerall = command = c
triggerall = command != holddown
triggerall = P2Bodydist X > 25
trigger1 = statetype = S
trigger1 = ctrl = 1
;chains from standing light or medium attacks (kicks, 200 to 210)
trigger2 = stateno >= 200
trigger2 = stateno <= 211
trigger2 = movecontact = 1
;punches (230 to 240)
trigger3 = stateno >= 230
trigger3 = stateno <= 242
trigger3 = movecontact = 1
;---------------------------------------------------------------------------
;Stand_X- left jab
[State -1]
type = ChangeState
value = 230
triggerall = command = x          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl = 1
;rapid-fire after right jab
trigger2= stateno =231
trigger2= time >= 8

;---------------------------------------------------------------------------
;Stand_X- right jab
[State -1]
type = ChangeState
value = 231
triggerall = command = x          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
;rapid-fire after left jab
trigger1= stateno =230
trigger1= time >= 8
;---------------------------------------------------------------------------
;Stand_Y- basic straight medium punch
[State -1]
type = ChangeState
value = 240
triggerall = command = y
triggerall = command != holddown
triggerall = P2BodyDist X > 10
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;chains from light kicks
trigger2 = stateno >= 200
trigger2 = stateno <= 202
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
;chains from standing jab
trigger3= stateno >= 230
trigger3= stateno <= 231
trigger3= movecontact = 1
;chain from tucked uppers
trigger4= stateno =241
trigger4= movecontact=1
trigger5= stateno =242
trigger5= movecontact=1

;---------------------------------------------------------------------------
;Stand_Y- tucked left uppercut
[State -1]
type = ChangeState
value = 241
triggerall = command = y
triggerall = command != holddown
triggerall = P2BodyDist X <= 10
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;chains from light kicks
trigger2 = stateno >= 200
trigger2 = stateno <= 202
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
;chains from standing right jab 
trigger3= stateno = 231
trigger3= movecontact = 1
;chains from tucked right upper
trigger4= stateno = 242
trigger4= movecontact = 1

;---------------------------------------------------------------------------
;Stand_Y- tucked right uppercut
[State -1]
type = ChangeState
value = 242
triggerall = command = y
triggerall = command != holddown
triggerall = P2BodyDist X <= 10
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;chains from light kicks
trigger2 = stateno >= 200
trigger2 = stateno <= 202
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
;chains from standing left jab 
trigger3= stateno = 230
trigger3= movecontact = 1
;chains from tucked left upper
trigger4= stateno = 241
trigger4= movecontact = 1
;---------------------------------------------------------------------------
;Stand_Z- double fist smash
[State -1]
type = ChangeState
value = 250
triggerall = command = z
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
;chains from standing light or medium attacks (kicks, 200 to 210)
trigger2 = stateno >= 200
trigger2 = stateno <= 211
trigger2 = movecontact = 1
;punches (230 to 240)
trigger3 = stateno >= 230
trigger3 = stateno <= 242
trigger3 = stateno != 240
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_Z- lunging left after straight medium right
[State -1]
type = ChangeState
value = 251
triggerall = command = z
triggerall = command != holddown
trigger1 = stateno = 240
trigger1 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 400
triggerall = command = a
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;rapid-fire
trigger2 = stateno =400
trigger2 = time >= 7


;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 410
triggerall = command = b
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;chains from light low attacks
trigger2 = stateno =400
trigger2 = movecontact = 1
trigger3 = stateno =430
trigger3 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch_C
[State -1]
type = ChangeState
value = 420
triggerall = command = c
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;chains from light low attacks
trigger2 = stateno =400
trigger2 = movecontact = 1
trigger3 = stateno =430
trigger3 = movecontact = 1
;chains from medium low attacks
trigger4 = stateno = 410
trigger4 = movecontact = 1
trigger5 = stateno = 440
trigger5 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch_X
[State -1]
type = ChangeState
value = 430
triggerall = command = x
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;rapid-fire
trigger2 = stateno =430
trigger2 = time >= 7
;---------------------------------------------------------------------------
;Crouch_Y
[State -1]
type = ChangeState
value = 440
triggerall = command = y
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;chains from light low attacks
trigger2 = stateno =400
trigger2 = movecontact = 1
trigger3 = stateno =430
trigger3 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch_Z
[State -1]
type = ChangeState
value = 450
triggerall = command = z
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;chains from light low attacks
trigger2 = stateno =400
trigger2 = movecontact = 1
trigger3 = stateno =430
trigger3 = movecontact = 1
;chains from medium low attacks
trigger4 = stateno = 410
trigger4 = movecontact = 1
trigger5 = stateno = 440
trigger5 = movecontact = 1
;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 600
triggerall = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1


;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 610
triggerall = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1
;chains from light flying attacks
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 630
trigger3 = movecontact = 1
;---------------------------------------------------------------------------
;Jump_C
[State -1]
type = ChangeState
value = 620
triggerall = command = c
trigger1 = statetype = A
trigger1 = ctrl = 1
;chains from light flying attacks
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 630
trigger3 = movecontact = 1
;chains from medium flying attacks
trigger4 = stateno = 610
trigger4 = movecontact = 1
trigger5 = stateno = 640
trigger5 = movecontact = 1
;---------------------------------------------------------------------------
;Jump_X
[State -1]
type = ChangeState
value = 630
triggerall = command = x
trigger1 = statetype = A
trigger1 = ctrl = 1


;---------------------------------------------------------------------------
;Jump_Y
[State -1]
type = ChangeState
value = 640
triggerall = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1
;chains from light flying attacks
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 630
trigger3 = movecontact = 1
;---------------------------------------------------------------------------
;Jump_Z
[State -1]
type = ChangeState
value = 650
triggerall = command = z
trigger1 = statetype = A
trigger1 = ctrl = 1
;chains from light flying attacks
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 630
trigger3 = movecontact = 1
;chains from medium flying attacks
trigger4 = stateno = 610
trigger4 = movecontact = 1
trigger5 = stateno = 640
trigger5 = movecontact = 1

;Taunt
[State -1]
type = Changestate
value = 1300
trigger1 = command = s
trigger1 = statetype = S
trigger1 = ctrl = 1

